==> nextcloud-28.0.7.tgz: nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given legal notice address is not a valid URL" : "O endereço do aviso legal não é uma URL válida",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "Disable-user-theming should be true or false" : "Desabilitar-tema-usuário deve ser verdadeiro ou falso",
    "Saved" : "Salva",
    "Invalid app given" : "Aplicativo inválido fornecido",
    "Invalid type for setting \"defaultApp\" given" : "Tipo inválido para configuração de \"defaultApp\" fornecido",
    "Invalid setting key" : "Chave de configuração inválida",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "PHP Imagick module" : "Módulo PHP Imageck",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP \"imagick\" não está habilitado, embora o aplicativo de temas esteja. Para que a geração de favicon funcione corretamente, você precisa instalar e habilitar este módulo.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "O módulo PHP \"imagick\" neste caso não tem suporte a SVG. Para melhor compatibilidade é recomendado instalá-lo.",
    "Dark theme with high contrast mode" : "Tema escuro com modo de alto contraste",
    "Enable dark high contrast mode" : "Ative o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semelhante ao modo de alto contraste, mas com cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Um tema escuro para aliviar seus olhos, reduzindo a luminosidade e o brilho gerais.",
    "System default theme" : "Tema padrão do sistema",
    "Enable the system default" : "Ativar o padrão do sistema",
    "Using the default system appearance." : "Usando a aparência padrão do sistema.",
    "Dyslexia font" : "Fonte de dislexia",
    "Enable dyslexia font" : "Ativar fonte dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é um tipo de letra/fonte grátis concebida para atenuar alguns dos erros comuns de leitura causados pela dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Ativar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "O modo de alto contraste facilita a navegação. A qualidade visual será reduzida, mas a clareza será aumentada.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Ative o tema de luz padrão",
    "The default light appearance." : "A aparência de luz padrão.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Em vez de uma imagem de fundo você também pode configurar uma cor de fundo simples. Se você usar uma imagem de fundo, a alteração dessa cor influenciará a cor dos ícones do menu do aplicativo.",
    "Background color" : "Cor de fundo",
    "Upload new logo" : "Enviar novo logotipo",
    "Logo" : "Logotipo",
    "Upload new background and login image" : "Envie um novo papel de parede e imagem de login",
    "Background and login image" : "Plano de fundo e imagem de login",
    "Advanced options" : "Opções avançadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP ImageMagick para ter suporte a geração automática em SVG para favicons baseados no logotipo e cores enviados.",
    "Name" : "Nome",
    "Web link" : "Link web",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Slogan" : "Slogan",
    "Primary color" : "Cor primária",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "A cor primária é usada para destacar elementos como botões importantes. Pode ser ligeiramente ajustado dependendo do esquema de cores atual.",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "User settings" : "Configurações de usuário",
    "Disable user theming" : "Desabilitar temas do usuário",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Embora você possa selecionar e personalizar a sua instância, os usuários podem alterar seu plano de fundo e as cores. Se você quiser forçar a sua personalização, marque esta caixa.",
    "Appearance and accessibility settings" : "Configurações de aparência e acessibilidade",
    "Customization has been disabled by your administrator" : "A personalização foi desativada pelo seu administrador",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Defina uma cor primária para destacar elementos importantes. A cor usada para elementos como botões primários pode diferir um pouco à medida que é ajustada para atender aos requisitos de acessibilidade.",
    "Background and color" : "Fundo e cor",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "O plano de fundo pode ser definido como uma imagem do conjunto padrão, uma imagem personalizada carregada ou uma cor simples.",
    "Keyboard shortcuts" : "Atalhos do teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
    "Disable all keyboard shortcuts" : "Desabilitar todos os atalhos de teclado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicativo atualmente selecionado: {app}, posição {position} de {total}",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Custom background" : "Papel de parede personalizado",
    "Plain background" : "Fundo simples",
    "Default background" : "Papel de parede padrão",
    "Select a background from your files" : "Selecione o papel de parede de seus arquivos",
    "Select background" : "Selecione o plano de fundo",
    "No background has been selected" : "Nenhum plano de fundo foi selecionado",
    "Theme selection is enforced" : "A seleção do tema é aplicada",
    "Navigation bar settings" : "Configurações da barra de navegação",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Você pode configurar a ordem do aplicativo usada na barra de navegação. A primeira entrada será o aplicativo padrão, aberto após o login ou ao clicar no logotipo.",
    "The default app can not be changed because it was configured by the administrator." : "O aplicativo padrão não pode ser alterado porque foi configurado pelo administrador.",
    "The app order was changed, to see it in action you have to reload the page." : "A ordem do aplicativo foi alterada, para vê-lo em ação é necessário recarregar a página.",
    "Reset default app order" : "Redefinir a ordem padrão dos aplicativos",
    "Could not set the app order" : "Não foi possível definir a ordem do aplicativo",
    "Could not reset the app order" : "Não foi possível redefinir a ordem do aplicativo",
    "Reset primary color" : "Redefinir cor primária",
    "Could not set primary color" : "Não foi possível definir a cor primária",
    "Default app" : "Aplicativo padrão",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "O aplicativo padrão é o aplicativo que é, por exemplo. aberto após o login ou quando o logotipo no menu é clicado.",
    "Use custom default app" : "Usar aplicativo padrão personalizado",
    "Global default app" : "Aplicativo padrão global",
    "Global default apps" : "Aplicativos padrão globais",
    "Default app priority" : "Prioridade padrão do aplicativo",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Se um aplicativo não estiver habilitado para um usuário, o próximo aplicativo com prioridade mais baixa será usado.",
    "Could not set global default apps" : "Não foi possível definir aplicativos padrão globais",
    "Select a custom color" : "Selecione uma cor personalizada",
    "Reset to default" : "Redefinir para o padrão",
    "Upload" : "Enviar",
    "Remove background image" : "Excluir a imagem de fundo",
    "Color" : "Cor",
    "Background" : "Fundo",
    "Set a custom background" : "Defina um plano de fundo personalizado",
    "Change color" : "Trocar a cor",
    "No background" : "Sem fundo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given legal notice address is not a valid URL" : "O endereço do aviso legal não é uma URL válida",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "Disable-user-theming should be true or false" : "Desabilitar-tema-usuário deve ser verdadeiro ou falso",
    "Saved" : "Salva",
    "Invalid app given" : "Aplicativo inválido fornecido",
    "Invalid type for setting \"defaultApp\" given" : "Tipo inválido para configuração de \"defaultApp\" fornecido",
    "Invalid setting key" : "Chave de configuração inválida",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Appearance and accessibility" : "Aparência e acessibilidade",
    "PHP Imagick module" : "Módulo PHP Imageck",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP \"imagick\" não está habilitado, embora o aplicativo de temas esteja. Para que a geração de favicon funcione corretamente, você precisa instalar e habilitar este módulo.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "O módulo PHP \"imagick\" neste caso não tem suporte a SVG. Para melhor compatibilidade é recomendado instalá-lo.",
    "Dark theme with high contrast mode" : "Tema escuro com modo de alto contraste",
    "Enable dark high contrast mode" : "Ative o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semelhante ao modo de alto contraste, mas com cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Enable dark theme",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Um tema escuro para aliviar seus olhos, reduzindo a luminosidade e o brilho gerais.",
    "System default theme" : "Tema padrão do sistema",
    "Enable the system default" : "Ativar o padrão do sistema",
    "Using the default system appearance." : "Usando a aparência padrão do sistema.",
    "Dyslexia font" : "Fonte de dislexia",
    "Enable dyslexia font" : "Ativar fonte dislexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é um tipo de letra/fonte grátis concebida para atenuar alguns dos erros comuns de leitura causados pela dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Ativar modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "O modo de alto contraste facilita a navegação. A qualidade visual será reduzida, mas a clareza será aumentada.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Ative o tema de luz padrão",
    "The default light appearance." : "A aparência de luz padrão.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Em vez de uma imagem de fundo você também pode configurar uma cor de fundo simples. Se você usar uma imagem de fundo, a alteração dessa cor influenciará a cor dos ícones do menu do aplicativo.",
    "Background color" : "Cor de fundo",
    "Upload new logo" : "Enviar novo logotipo",
    "Logo" : "Logotipo",
    "Upload new background and login image" : "Envie um novo papel de parede e imagem de login",
    "Background and login image" : "Plano de fundo e imagem de login",
    "Advanced options" : "Opções avançadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP ImageMagick para ter suporte a geração automática em SVG para favicons baseados no logotipo e cores enviados.",
    "Name" : "Nome",
    "Web link" : "Link web",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Slogan" : "Slogan",
    "Primary color" : "Cor primária",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "A cor primária é usada para destacar elementos como botões importantes. Pode ser ligeiramente ajustado dependendo do esquema de cores atual.",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "User settings" : "Configurações de usuário",
    "Disable user theming" : "Desabilitar temas do usuário",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Embora você possa selecionar e personalizar a sua instância, os usuários podem alterar seu plano de fundo e as cores. Se você quiser forçar a sua personalização, marque esta caixa.",
    "Appearance and accessibility settings" : "Configurações de aparência e acessibilidade",
    "Misc accessibility options" : "Várias opções de acessibilidade",
    "Enable blur background filter (may increase GPU load)" : "Ativar o filtro de fundo de desfoque (pode aumentar a carga da GPU)",
    "Customization has been disabled by your administrator" : "A personalização foi desativada pelo seu administrador",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Defina uma cor primária para destacar elementos importantes. A cor usada para elementos como botões primários pode diferir um pouco à medida que é ajustada para atender aos requisitos de acessibilidade.",
    "Background and color" : "Fundo e cor",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "O plano de fundo pode ser definido como uma imagem do conjunto padrão, uma imagem personalizada carregada ou uma cor simples.",
    "Keyboard shortcuts" : "Atalhos do teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
    "Disable all keyboard shortcuts" : "Desabilitar todos os atalhos de teclado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Aplicativo atualmente selecionado: {app}, posição {position} de {total}",
    "Move up" : "Mover para cima",
    "Move down" : "Mover para baixo",
    "Custom background" : "Papel de parede personalizado",
    "Plain background" : "Fundo simples",
    "Default background" : "Papel de parede padrão",
    "Select a background from your files" : "Selecione o papel de parede de seus arquivos",
    "Select background" : "Selecione o plano de fundo",
    "No background has been selected" : "Nenhum plano de fundo foi selecionado",
    "Theme selection is enforced" : "A seleção do tema é aplicada",
    "Navigation bar settings" : "Configurações da barra de navegação",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Você pode configurar a ordem do aplicativo usada na barra de navegação. A primeira entrada será o aplicativo padrão, aberto após o login ou ao clicar no logotipo.",
    "The default app can not be changed because it was configured by the administrator." : "O aplicativo padrão não pode ser alterado porque foi configurado pelo administrador.",
    "The app order was changed, to see it in action you have to reload the page." : "A ordem do aplicativo foi alterada, para vê-lo em ação é necessário recarregar a página.",
    "Reset default app order" : "Redefinir a ordem padrão dos aplicativos",
    "Could not set the app order" : "Não foi possível definir a ordem do aplicativo",
    "Could not reset the app order" : "Não foi possível redefinir a ordem do aplicativo",
    "Reset primary color" : "Redefinir cor primária",
    "Could not set primary color" : "Não foi possível definir a cor primária",
    "Default app" : "Aplicativo padrão",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "O aplicativo padrão é o aplicativo que é, por exemplo. aberto após o login ou quando o logotipo no menu é clicado.",
    "Use custom default app" : "Usar aplicativo padrão personalizado",
    "Global default app" : "Aplicativo padrão global",
    "Global default apps" : "Aplicativos padrão globais",
    "Default app priority" : "Prioridade padrão do aplicativo",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Se um aplicativo não estiver habilitado para um usuário, o próximo aplicativo com prioridade mais baixa será usado.",
    "Could not set global default apps" : "Não foi possível definir aplicativos padrão globais",
    "Select a custom color" : "Selecione uma cor personalizada",
    "Reset to default" : "Redefinir para o padrão",
    "Upload" : "Enviar",
    "Remove background image" : "Excluir a imagem de fundo",
    "Color" : "Cor",
    "Background" : "Fundo",
    "Set a custom background" : "Defina um plano de fundo personalizado",
    "Change color" : "Trocar a cor",
    "No background" : "Sem fundo"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
